@@ -207,9 +207,10 @@ DisplayTodaysComment (sotsuval sv)
     {45, "煙草友達の喫煙の誘いには注意してください"},
     {45, "飲み会では特に注意してください"},
     {44, "卒煙して４４日目です。アヒル副隊長が喜んでいます"},
-    {34, "油断は禁物です。一本だけオバケに注意してください"},
-    {34, "煙草友達の喫煙の誘いには注意してください"},
-    {34, "飲み会では特に注意してください"},
+    {36, "油断は禁物です。一本だけオバケに注意してください"},
+    {36, "煙草友達の喫煙の誘いには注意してください"},
+    {36, "飲み会では特に注意してください"},
+    {35, "卒煙して１ヶ月越えしましたが、油断は大敵です"},
     {34, "そつえん いっかげつ おめでとぉー　がぁーがぁーがぁー"},
     {33,
      "卒煙して３３日目です。アヒルの王様がお祝いに来ました"},
@@ -288,17 +289,21 @@ DisplayTodaysComment (sotsuval sv)
 
   GRand *r = g_rand_new ();
   int i = 0;
+	
   while (1)
     {
       if (sv.eDay >= TableCmt[i].tDay)
 	{
-	  while (sv.eDay == TableCmt[i + 1].tDay && g_rand_int (r) % 2)
+	  //while (sv.eDay == TableCmt[i + 1].tDay && g_rand_int (r) % 2) //08.06.19 bug fix
+	  while (TableCmt[i + 1].tDay == TableCmt[i].tDay && g_rand_int (r) % 2)
 	    i++;
 	  strcpy (DispCmt, TableCmt[i].tmsg);
 	  break;
-	}
+	}else{
       i++;
-    }
+	}
+		}
+
 //  g_print ("sv.Month:%d", sv.Month);
   if (sv.Year == 0 && g_rand_int (r) % 2)
     {
@@ -350,7 +355,8 @@ DisplayTodaysComment (sotsuval sv)
 	  break;
 	}
     }
-  if (sv.Year == 1 && g_rand_int (r) % 2)
+  //if (sv.Year == 1 && g_rand_int (r) % 2) //08.06.19 bug fix
+  if (sv.Year >= 1)
     {
       strcpy (DispCmt,
 	      "～ ご卒煙おめでとうございます ～");
